<?php defined('SYSPATH') or die('No direct script access.');

return array(

	'uncountable' => array(
		'access',
		'advice',
		'aircraft',
		'art',
		'baggage',
		'bison',
		'dances',
		'deer',
		'equipment',
		'fish',
		'fuel',
		'furniture',
		'heat',
		'honey',
		'homework',
		'impatience',
		'information',
		'knowledge',
		'luggage',
		'media',
		'money',
		'moose',
		'music',
		'news',
		'patience',
		'progress',
		'pollution',
		'research',
		'rice',
		'salmon',
		'sand',
		'series',
		'sheep',
		'sms',
		'spam',
		'species',
		'staff',
		'swine',
		'toothpaste',
		'traffic',
		'understanding',
		'water',
		'weather',
		'work',
	),

	'irregular' => array(
		'appendix' => 'appendices',
		'cactus' => 'cacti',
		'calf' => 'calves',
		'child' => 'children',
		'crisis' => 'crises',
		'criterion' => 'criteria',
		'curriculum' => 'curricula',
		'diagnosis' => 'diagnoses',
		'elf' => 'elves',
		'ellipsis' => 'ellipses',
		'foot' => 'feet',
		'goose' => 'geese',
		'hero' => 'heroes',
		'hoof' => 'hooves',
		'hypothesis' => 'hypotheses',
		'is' => 'are',
		'knife' => 'knives',
		'leaf' => 'leaves',
		'life' => 'lives',
		'loaf' => 'loaves',
		'man' => 'men',
		'mouse' => 'mice',
		'nucleus' => 'nuclei',
		'oasis' => 'oases',
		'octopus' => 'octopi',
		'ox' => 'oxen',
		'paralysis' => 'paralyses',
		'parenthesis' => 'parentheses',
		'person' => 'people',
		'phenomenon' => 'phenomena',
		'potato' => 'potatoes',
		'quiz' => 'quizzes',
		'radius' => 'radii',
		'scarf' => 'scarves',
		'stimulus' => 'stimuli',
		'syllabus' => 'syllabi',
		'synthesis' => 'syntheses',
		'thief' => 'thieves',
		'tooth' => 'teeth',
		'was' => 'were',
		'wharf' => 'wharves',
		'wife' => 'wives',
		'woman' => 'women',
		'release' => 'releases',
	),
);
